<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.0" language="ru_RU">
<context>
    <name>GB2::LocalWorkflow::MusclePrompter</name>
    <message>
        <location filename="../src/MuscleWorker.cpp" line="70"/>
        <source> from %1</source>
        <translation> из %1</translation>
    </message>
    <message>
        <location filename="../src/MuscleWorker.cpp" line="78"/>
        <source>For each MSA&lt;u&gt;%1&lt;/u&gt;, build the alignment using &lt;u&gt;&quot;%2&quot; preset&lt;/u&gt; and send it to output.</source>
        <translation>Для каждого выравнивания&lt;u&gt;%1&lt;/u&gt;, запустить MUSCLE в конфигурации &lt;u&gt;&quot;%2&quot;&lt;/u&gt; и выдать результат на  выход.</translation>
    </message>
</context>
<context>
    <name>GB2::LocalWorkflow::MuscleWorker</name>
    <message>
        <location filename="../src/MuscleWorker.cpp" line="31"/>
        <source>Input MSA</source>
        <translation>Входное выравнивание</translation>
    </message>
    <message>
        <location filename="../src/MuscleWorker.cpp" line="32"/>
        <source>Multiple sequence alignment</source>
        <translation>Множественное выравнивание</translation>
    </message>
    <message>
        <location filename="../src/MuscleWorker.cpp" line="43"/>
        <source>MUSCLE alignment</source>
        <translation>Выравнивание MUSCLE</translation>
    </message>
    <message>
        <location filename="../src/MuscleWorker.cpp" line="35"/>
        <source>Mode</source>
        <translation>Конфигурация</translation>
    </message>
    <message>
        <location filename="../src/MuscleWorker.cpp" line="37"/>
        <source>Stable order</source>
        <translation>Сохранять порядок</translation>
    </message>
    <message>
        <location filename="../src/MuscleWorker.cpp" line="31"/>
        <source>Multiple sequence alignment to be processed.</source>
        <translation>Входные данные для выравнивания.</translation>
    </message>
    <message>
        <location filename="../src/MuscleWorker.cpp" line="32"/>
        <source>Result of alignment.</source>
        <translation>Результат выравнивания.</translation>
    </message>
    <message>
        <location filename="../src/MuscleWorker.cpp" line="44"/>
        <source>MUSCLE is public domain multiple alignment software for protein and nucleotide sequences.&lt;p&gt;&lt;dfn&gt;MUSCLE stands for MUltiple Sequence Comparison by Log-Expectation.&lt;/dfn&gt;&lt;/p&gt;</source>
        <translation>Пакет MUSCLE предназначен для выравнивания множественных протеиновых и нуклеотидных последовательностей.</translation>
    </message>
    <message>
        <location filename="../src/MuscleWorker.cpp" line="116"/>
        <source>Aligned %1 with MUSCLE</source>
        <translation>Выровнял %1 с MUSCLE</translation>
    </message>
    <message>
        <location filename="../src/MuscleWorker.cpp" line="36"/>
        <source>Selector of preset configurations, that give you the choice of optimizing accuracy, speed, or some compromise between the two. The default favors accuracy.</source>
        <translation>Выбор между режимами максимальной точности, скорости либо компромиса между ними. По умолчанию оптимизируется точность выравнивания.</translation>
    </message>
    <message>
        <location filename="../src/MuscleWorker.cpp" line="38"/>
        <source>Do not rearrange aligned sequences (-stable switch of MUSCLE). &lt;p&gt;Otherwise, MUSCLE re-arranges sequences so that similar sequences are adjacent in the output file. This makes the alignment easier to evaluate by eye. </source>
        <translation>Сохранять начальный порядок последовательностей в выравнивании. &lt;p&gt;Иначе, MUSCLE группирует похожие последовательности в выходном выравнивании, для удобства визуального сравнения.</translation>
    </message>
</context>
<context>
    <name>GB2::MuscleAdapter</name>
    <message>
        <location filename="../src/MuscleAdapter.cpp" line="50"/>
        <source>No sequences in input file</source>
        <translation>Выравнивание не содержит данных</translation>
    </message>
    <message>
        <location filename="../src/MuscleAdapter.cpp" line="77"/>
        <source>alignment_is_empty</source>
        <translation>Выравнивание не содержит данных</translation>
    </message>
    <message>
        <location filename="../src/MuscleAdapter.cpp" line="28"/>
        <location filename="../src/MuscleAdapter.cpp" line="176"/>
        <location filename="../src/MuscleAdapter.cpp" line="263"/>
        <location filename="../src/MuscleAdapter.cpp" line="452"/>
        <source>Internal MUSCLE error: %1</source>
        <translation>Внутренняя ошибка MUSCLE: %1</translation>
    </message>
    <message>
        <location filename="../src/MuscleAdapter.cpp" line="256"/>
        <source>Invalid input alignment</source>
        <translation>Некорректное входное выравнивание</translation>
    </message>
    <message>
        <location filename="../src/MuscleAdapter.cpp" line="272"/>
        <location filename="../src/MuscleAdapter.cpp" line="463"/>
        <source>Incompatible alphabets</source>
        <translation>Несовместимые алфавиты</translation>
    </message>
    <message>
        <location filename="../src/MuscleAdapter.cpp" line="301"/>
        <source>Aligning profiles</source>
        <translation>Выравнивание</translation>
    </message>
    <message>
        <location filename="../src/MuscleAdapter.cpp" line="304"/>
        <source>Building output</source>
        <translation>Подготовка результата</translation>
    </message>
    <message>
        <location filename="../src/MuscleAdapter.cpp" line="445"/>
        <source>Profile is not aligned</source>
        <translation>Выравнивание не нормализовано</translation>
    </message>
    <message>
        <location filename="../src/MuscleAdapter.cpp" line="492"/>
        <source>Aligning sequence %1 of %2</source>
        <translation>Выравнивается последовательность %1 из %2</translation>
    </message>
    <message>
        <location filename="../src/MuscleAdapter.cpp" line="524"/>
        <source>Merging results: %1 of %2</source>
        <translation>Объединяются результаты: %1 из %2</translation>
    </message>
    <message>
        <location filename="../src/MuscleUtils.cpp" line="69"/>
        <source>Unsupported alphabet: %1</source>
        <translation>Неподходящий алфавит: %1 </translation>
    </message>
</context>
<context>
    <name>GB2::MuscleAddSequencesToProfileTask</name>
    <message>
        <location filename="../src/MuscleTask.cpp" line="198"/>
        <source>MUSCLE align profiles &apos;%1&apos; vs &apos;%2&apos;</source>
        <translation>MUSCLE выравнивает &apos;%1&apos; к &apos;%2&apos;</translation>
    </message>
    <message>
        <location filename="../src/MuscleTask.cpp" line="200"/>
        <source>MUSCLE align &apos;%2&apos; by profile &apos;%1&apos;</source>
        <translation>MUSCLE добавляет &apos;%2&apos; к &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/MuscleTask.cpp" line="216"/>
        <source>input_format_error</source>
        <translation>Не удалось определить формат файла</translation>
    </message>
    <message>
        <location filename="../src/MuscleTask.cpp" line="253"/>
        <source>Sequences in file have different alphabets %1</source>
        <translation>Последовательности в файле имеют разные алфавиты: %1</translation>
    </message>
    <message>
        <location filename="../src/MuscleTask.cpp" line="271"/>
        <source>No sequences found in file %1</source>
        <translation>Файл не содержит последовательностей: %1</translation>
    </message>
    <message>
        <location filename="../src/MuscleTask.cpp" line="273"/>
        <source>No alignment found in file %1</source>
        <translation>Файл не содержит выравниваний: %1</translation>
    </message>
</context>
<context>
    <name>GB2::MuscleAlignDialogController</name>
    <message>
        <location filename="../src/MuscleAlignDialogController.cpp" line="47"/>
        <source>Error</source>
        <translation>Ошибка</translation>
    </message>
    <message>
        <location filename="../src/MuscleAlignDialogController.cpp" line="47"/>
        <source>Illegal alignment region</source>
        <translation>Неправильный регион</translation>
    </message>
    <message>
        <location filename="../src/MuscleAlignDialogController.cpp" line="84"/>
        <location filename="../src/MuscleAlignDialogController.cpp" line="87"/>
        <source>Selecting machines error!</source>
        <translation>Ошибка выбора удаленных машин!</translation>
    </message>
    <message>
        <location filename="../src/MuscleAlignDialogController.cpp" line="84"/>
        <source>You didn&apos;t select a machine to run remote task!</source>
        <translation>Не выбрана машина для удаленного запуска!</translation>
    </message>
    <message>
        <location filename="../src/MuscleAlignDialogController.cpp" line="88"/>
        <source>Distributed run on many machines is not supported yet. Select 1 machine</source>
        <translation>Распределенный запуск на нескольких машинах в данный пока не поддерживается. Выберите одну машину</translation>
    </message>
    <message>
        <location filename="../src/MuscleAlignDialogController.cpp" line="112"/>
        <source>MUSCLE default</source>
        <translation>По умолчанию</translation>
    </message>
    <message>
        <location filename="../src/MuscleAlignDialogController.cpp" line="113"/>
        <source>&lt;p&gt;The default settings are designed to give the best accuracy</source>
        <translation>&lt;p&gt;Наилучшая точность выравнивания</translation>
    </message>
    <message>
        <location filename="../src/MuscleAlignDialogController.cpp" line="114"/>
        <source>&lt;p&gt;&lt;b&gt;Command line:&lt;/b&gt; muscle &lt;no-parameters&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Командная строка:&lt;/b&gt; muscle &lt;no-parameters&gt;</translation>
    </message>
    <message>
        <location filename="../src/MuscleAlignDialogController.cpp" line="118"/>
        <source>Large alignment</source>
        <translation>Большие выравнивания</translation>
    </message>
    <message>
        <location filename="../src/MuscleAlignDialogController.cpp" line="119"/>
        <source>&lt;p&gt;If you have a large number of sequences (a few thousand), or they are very long, then the default settings may be too slow for practical use. A good compromise between speed and accuracy is to run just the first two iterations of the algorithm</source>
        <translation>&lt;p&gt;При наличии тысяч последовательностей либо их большой длине, конфигурация по умолчанию может оказаться неприемлемо медленной. Хороший компромисс между скоростью и точностью обеспечивается при прогоне только первых 2-х итераций алгоритма. </translation>
    </message>
    <message>
        <location filename="../src/MuscleAlignDialogController.cpp" line="120"/>
        <source>&lt;p&gt;&lt;b&gt;Command line:&lt;/b&gt; muscle &lt;i&gt;-maxiters 2&lt;/i&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Командная строка:&lt;/b&gt; muscle &lt;i&gt;-maxiters 2&lt;/i&gt;</translation>
    </message>
    <message>
        <location filename="../src/MuscleAlignDialogController.cpp" line="124"/>
        <source>Refine only</source>
        <translation>Только улучшить</translation>
    </message>
    <message>
        <location filename="../src/MuscleAlignDialogController.cpp" line="125"/>
        <source>&lt;p&gt;Improves existing alignment without complete realignment</source>
        <translation>&lt;p&gt;Улучшение существующего выравнивания</translation>
    </message>
    <message>
        <location filename="../src/MuscleAlignDialogController.cpp" line="126"/>
        <source>&lt;p&gt;&lt;b&gt;Command line:&lt;/b&gt; muscle &lt;i&gt;-refine&lt;/i&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;Командная строка:&lt;/b&gt; muscle &lt;i&gt;-refine&lt;/i&gt;</translation>
    </message>
</context>
<context>
    <name>GB2::MuscleGObjectTask</name>
    <message>
        <location filename="../src/MuscleTask.cpp" line="299"/>
        <source>MUSCLE align &apos;%1&apos;</source>
        <translation>MUSCLE выравнивает &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/MuscleTask.cpp" line="302"/>
        <source>MUSCLE refine &apos;%1&apos;</source>
        <translation>MUSCLE улучшает &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/MuscleTask.cpp" line="305"/>
        <source>MUSCLE add to profile &apos;%1&apos;</source>
        <translation>MUSCLE добавляет в выравнивание &apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/MuscleTask.cpp" line="308"/>
        <source>MUSCLE align profiles</source>
        <translation>MUSCLE выравнивает пару выравниваний</translation>
    </message>
    <message>
        <location filename="../src/MuscleTask.cpp" line="323"/>
        <source>object_removed</source>
        <translation>Объект был удалён</translation>
    </message>
    <message>
        <location filename="../src/MuscleTask.cpp" line="327"/>
        <location filename="../src/MuscleTask.cpp" line="350"/>
        <source>object_is_state_locked</source>
        <translation>Объект заблокирован</translation>
    </message>
</context>
<context>
    <name>GB2::MuscleLocalTask</name>
    <message>
        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="149"/>
        <source>Muscle local task</source>
        <translation>Внешняя задача выравнивания Muscle</translation>
    </message>
    <message>
        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="150"/>
        <source>No settings given</source>
        <translation>Не заданы настройки задачи</translation>
    </message>
    <message>
        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="153"/>
        <source>Muscle local task. Alignment: %1</source>
        <translation>Внешняя задача выравнивания Muscle. Множественное выравнивание:&apos;%1&apos;</translation>
    </message>
    <message>
        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="190"/>
        <source>Alien Muscle task from remote machine.</source>
        <translation>Внешняя задача выравнивания Muscle с удаленной машины.</translation>
    </message>
    <message>
        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="191"/>
        <source>Alignment</source>
        <translation>Множественное выравнивание</translation>
    </message>
    <message>
        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="194"/>
        <source>Task finished with error</source>
        <translation>Задача завершилась с ошибкой</translation>
    </message>
</context>
<context>
    <name>GB2::MuscleMSAEditorContext</name>
    <message>
        <location filename="../src/MusclePlugin.cpp" line="102"/>
        <source>Align sequences to profile with MUSCLE</source>
        <translation>Выровнять с дополнительными последовательностями ...</translation>
    </message>
    <message>
        <location filename="../src/MusclePlugin.cpp" line="109"/>
        <source>Align profile to profile with MUSCLE</source>
        <translation>Выровнять с другим выравниванием ...</translation>
    </message>
    <message>
        <location filename="../src/MusclePlugin.cpp" line="162"/>
        <source>Select file with sequences</source>
        <translation>Выбор файла последовательностей</translation>
    </message>
    <message>
        <location filename="../src/MusclePlugin.cpp" line="177"/>
        <source>Select file with alignment</source>
        <translation>Выбор файла выравнивания</translation>
    </message>
    <message>
        <location filename="../src/MusclePlugin.cpp" line="95"/>
        <source>Align with MUSCLE</source>
        <translation>Выровнять ...</translation>
    </message>
</context>
<context>
    <name>GB2::MuscleParallelTask</name>
    <message>
        <location filename="../src/MuscleParallel.cpp" line="30"/>
        <source>MuscleParallelTask</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::MusclePlugin</name>
    <message>
        <location filename="../src/MusclePlugin.cpp" line="41"/>
        <source>MUSCLE</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/MusclePlugin.cpp" line="42"/>
        <source>A port of MUSCLE package for multiple sequence alignment. Check http://www.drive5.com/muscle/ for the original version</source>
        <translation>Порт пакета MUSCLE для выравнивания множественных последовательностей. ￼Сайт оригинального пакета http://www.drive5.com/muscle/</translation>
    </message>
</context>
<context>
    <name>GB2::MusclePrepareTask</name>
    <message>
        <location filename="../src/MuscleParallel.cpp" line="74"/>
        <source>Internal parallel MUSCLE error: %1</source>
        <translation>Внутренняя ошибка: %1</translation>
    </message>
    <message>
        <location filename="../src/MuscleParallel.cpp" line="114"/>
        <source>No sequences in input file</source>
        <translation>Выравнивание не содержит данных</translation>
    </message>
    <message>
        <location filename="../src/MuscleParallel.cpp" line="141"/>
        <source>alignment_is_empty</source>
        <translation>Выравнивание не содержит данных</translation>
    </message>
</context>
<context>
    <name>GB2::MuscleRemoteToGobjectTask</name>
    <message>
        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="211"/>
        <source>Malignment object removed</source>
        <translation>Объект множественного выравнивания удален</translation>
    </message>
    <message>
        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="215"/>
        <source>remote machine settings</source>
        <translation>настройки удаленной машины</translation>
    </message>
    <message>
        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="233"/>
        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="263"/>
        <source>MAlignment object is state locked</source>
        <translation>объект множественного выравнивания используется другой задачей</translation>
    </message>
    <message>
        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="242"/>
        <source>Cannot create remote machine</source>
        <translation>Не удалось создать удаленную машину</translation>
    </message>
    <message>
        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="269"/>
        <source>remote task didn&apos;t produced result</source>
        <translation>Удаленная задача не вернула результат</translation>
    </message>
    <message>
        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="280"/>
        <source>Muscle task runned on remote machine.</source>
        <translation>Задача Muscle, исполняющаяся на удаленной машине.</translation>
    </message>
    <message>
        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="282"/>
        <source>Alignment</source>
        <translation>Множественное выравнивание</translation>
    </message>
    <message>
        <location filename="../src/muscle_local_task/MuscleLocalTask.cpp" line="285"/>
        <source>Task finished with error</source>
        <translation>Задача завершилась с ошибкой</translation>
    </message>
</context>
<context>
    <name>GB2::MuscleTask</name>
    <message>
        <location filename="../src/MuscleTask.cpp" line="39"/>
        <source>MUSCLE alignment</source>
        <translation>Выравнивание MUSCLE</translation>
    </message>
</context>
<context>
    <name>GB2::ProgressiveAlignTask</name>
    <message>
        <location filename="../src/MuscleParallel.cpp" line="255"/>
        <source>ProgressiveAlignTask</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/MuscleParallel.cpp" line="277"/>
        <source>Internal parallel MUSCLE error: %1</source>
        <translation>Внутренняя ошибка: %1</translation>
    </message>
    <message>
        <location filename="../src/MuscleParallel.cpp" line="282"/>
        <source>alignment &quot;%1&quot; Parallel MUSCLE Iter 1 accomplished. Time elapsed %2 ms</source>
        <translation></translation>
    </message>
</context>
<context>
    <name>GB2::ProgressiveAlignWorker</name>
    <message>
        <location filename="../src/MuscleParallel.cpp" line="330"/>
        <source>ProgressiveAlignWorker</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/MuscleParallel.cpp" line="344"/>
        <source>Internal parallel MUSCLE error: %1</source>
        <translation>Внутренняя ошибка: %1</translation>
    </message>
</context>
<context>
    <name>GB2::RefineTask</name>
    <message>
        <location filename="../src/MuscleParallel.cpp" line="504"/>
        <source>RefineTask</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/MuscleParallel.cpp" line="527"/>
        <source>Internal parallel MUSCLE error: %1</source>
        <translation>Внутренняя ошибка: %1</translation>
    </message>
</context>
<context>
    <name>GB2::RefineTreeTask</name>
    <message>
        <location filename="../src/MuscleParallel.cpp" line="459"/>
        <source>RefineTreeTask</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/MuscleParallel.cpp" line="471"/>
        <source>Internal parallel MUSCLE error: %1</source>
        <translation>Внутренняя ошибка: %1</translation>
    </message>
</context>
<context>
    <name>GB2::RefineWorker</name>
    <message>
        <location filename="../src/MuscleParallel.cpp" line="581"/>
        <source>Internal parallel MUSCLE error: %1</source>
        <translation type="unfinished">Внутренняя ошибка: %1</translation>
    </message>
</context>
<context>
    <name>MuscleAlignmentDialog</name>
    <message>
        <location filename="../src/ui/MuscleAlignDialog.ui" line="14"/>
        <source>Align with MUSCLE</source>
        <translation>Выравнивание MUSCLE</translation>
    </message>
    <message>
        <location filename="../src/ui/MuscleAlignDialog.ui" line="28"/>
        <source>Configuration</source>
        <translation>Конфигурация</translation>
    </message>
    <message>
        <location filename="../src/ui/MuscleAlignDialog.ui" line="40"/>
        <source>Configuration details:</source>
        <translation>Описание:</translation>
    </message>
    <message>
        <location filename="../src/ui/MuscleAlignDialog.ui" line="54"/>
        <source>Advanced options</source>
        <translation>Дополнительные настройки</translation>
    </message>
    <message>
        <location filename="../src/ui/MuscleAlignDialog.ui" line="73"/>
        <source>Max iterations</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/MuscleAlignDialog.ui" line="112"/>
        <source>Max time (minutes)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/MuscleAlignDialog.ui" line="157"/>
        <source>Region to align</source>
        <translation>Выравнивать:</translation>
    </message>
    <message>
        <source>Custom range</source>
        <translation type="obsolete">Указанный регион</translation>
    </message>
    <message>
        <location filename="../src/ui/MuscleAlignDialog.ui" line="237"/>
        <source>-</source>
        <translation></translation>
    </message>
    <message>
        <location filename="../src/ui/MuscleAlignDialog.ui" line="176"/>
        <source>Whole alignment</source>
        <translation>Целые последовательности</translation>
    </message>
    <message>
        <location filename="../src/ui/MuscleAlignDialog.ui" line="186"/>
        <source>Column range</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../src/ui/MuscleAlignDialog.ui" line="278"/>
        <source>Remote run...</source>
        <translation>Удаленный запуск...</translation>
    </message>
    <message>
        <location filename="../src/ui/MuscleAlignDialog.ui" line="285"/>
        <source>Align</source>
        <translation>Выровнять</translation>
    </message>
    <message>
        <location filename="../src/ui/MuscleAlignDialog.ui" line="295"/>
        <source>Cancel</source>
        <translation>Отменить</translation>
    </message>
    <message>
        <location filename="../src/ui/MuscleAlignDialog.ui" line="60"/>
        <source>Do not re-arrange sequences (-stable)</source>
        <translation>Сохранять порядок последовательностей (ключ -stable)</translation>
    </message>
</context>
</TS>
